@@ -23,7 +23,6 @@
 
 #include <KJob>
 #include <QVariantMap>
-#include "ondemandextractor.h"
 
 namespace Baloo {
 
@@ -31,18 +30,11 @@ class FileFetchJob : public KJob
 {
     Q_OBJECT
 public:
-    enum class UseRealtimeIndexing : char {
-        Disabled = 0,
-        Only,
-        Fallback
-    };
-    explicit FileFetchJob(const QStringList& urls, bool canEditAll,
-        UseRealtimeIndexing useRealtime, QObject* parent = nullptr);
+    FileFetchJob(const QStringList& urls, QObject* parent = 0);
 
     QList<QVariantMap> data() const;
-    bool canEditAll() const;
 
-    void start() override;
+    virtual void start();
 
 private Q_SLOTS:
     void doStart();
@@ -50,9 +42,6 @@ private Q_SLOTS:
 private:
     QStringList m_urls;
     QList<QVariantMap> m_data;
-    bool m_canEditAll;
-    UseRealtimeIndexing m_useRealtime;
-    Private::OnDemandExtractor m_extractor;
 };
 }
 
